@@ -1,5 +1,5 @@
 #![no_std]
-#![allow(clippy::result_unit_err)]
+// #![allow(clippy::result_unit_err)]
 #![doc = include_str!("../README.md")]
 
 mod dataview;
@@ -8,7 +8,6 @@ mod view;
 
 use core::mem::size_of;
 use core::ptr;
-use endian::*;
 
 pub use dataview::DataView;
 pub use endian::Endian;
